@@ -104,7 +104,10 @@
   # statsd will periodically flush its metrics to Graphite
   # Be sure to include the Graphite backend above
   "graphitePort": 2003,
-  "graphiteHost": "graphite.domain.local",
+  "graphiteHost": "localhost", # your.graphite.host
+  "graphite": {
+    "legacyNamespace" : false
+  },
 
   ## Repeater backend is not implemented yet
   #"repeater": [ { "host": "10.1.2.3", "port": 8125 } ],
